@@ -63,7 +63,7 @@ ANIME_SPLIT_HOME = False
 ANIME_SPLIT_HOME_IN_TABS = False
 ANIMESUPPORT = False
 ANON_REDIRECT = None
-DEFAULT_ANON_REDIRECT = "https://blankrefer.com/?"
+DEFAULT_ANON_REDIRECT = "https://anonym.to/?"
 API_KEY = None
 API_ROOT = None
 AUTO_UPDATE = False
