@@ -544,40 +544,53 @@ class Home(WebRoot):
         data = {}
         size = 0
         for r in rows:
-            NotifyList = {"emails": "", "prowlAPIs": ""}
+            notify_list = {"emails": "", "prowlAPIs": ""}
             if r["notify_list"] and len(r["notify_list"]) > 0:
                 # First, handle legacy format (emails only)
                 if not r["notify_list"][0] == "{":
-                    NotifyList["emails"] = r["notify_list"]
+                    notify_list["emails"] = r["notify_list"]
                 else:
-                    NotifyList = dict(ast.literal_eval(r["notify_list"]))
+                    notify_list = dict(ast.literal_eval(r["notify_list"]))
 
-            data[r["show_id"]] = {"id": r["show_id"], "name": r["show_name"], "list": NotifyList["emails"], "prowl_notify_list": NotifyList["prowlAPIs"]}
-            size += 1
-        data["_size"] = size
+            data[r["show_id"]] = {"id": r["show_id"], "name": r["show_name"], "list": notify_list["emails"], "prowl_notify_list": notify_list["prowlAPIs"]}
+        data["_size"] = len(data)
         return json.dumps(data)
 
     def saveShowNotifyList(self):
+
         show = self.get_body_argument("show")
-        emails = self.get_body_argument("emails", "")
-        prowlAPIs = self.get_body_argument("prowlAPIs", "")
-
-        entries = {"emails": emails or "", "prowlAPIs": prowlAPIs or ""}
         main_db_con = db.DBConnection()
+        rows = main_db_con.select("SELECT show_id, notify_list FROM tv_shows WHERE show_id = ?", [show])
+        # Get existing data from db for both email and prowl
+        data = {}
 
-        # Get current data
-        for subs in main_db_con.select("SELECT notify_list FROM tv_shows WHERE show_id = ?", [show]):
-            if subs["notify_list"] and len(subs["notify_list"]) > 0:
+        for r in rows:
+            notify_list = {"emails": "", "prowlAPIs": ""}
+            if r["notify_list"] and len(r["notify_list"]) > 0:
                 # First, handle legacy format (emails only)
-                if not subs["notify_list"][0] == "{":
-                    entries["emails"] = subs["notify_list"]
+                if not r["notify_list"][0] == "{":
+                    notify_list["emails"] = r["notify_list"]
                 else:
-                    entries = dict(ast.literal_eval(subs["notify_list"]))
+                    notify_list = dict(ast.literal_eval(r["notify_list"]))
+            data = {"id": r["show_id"], "email_list": notify_list["emails"], "prowl_list": notify_list["prowlAPIs"]}
 
+        show_email = data["email_list"]
+        show_prowl = data["prowl_list"]
+
+        # Change email or prowl with new or keep the existing
+        emails = self.get_body_argument("emails", show_email)
+        prowlAPIs = self.get_body_argument("prowlAPIs", show_prowl)
+
+        entries = {"emails": emails, "prowlAPIs": prowlAPIs}
+
+        # TODO: Split emails and do validators.email
         if emails or prowlAPIs:
-            if not main_db_con.action("UPDATE tv_shows SET notify_list = ? WHERE show_id = ?", [str(entries), show]):
-                return "ERROR"
+            result = main_db_con.action("UPDATE tv_shows SET notify_list = ? WHERE show_id = ?", [str(entries), show])
+        else:
+            result = main_db_con.action("UPDATE tv_shows SET notify_list = Null WHERE show_id = ?", [show])
 
+        if not result:
+            return "ERROR"
         return "OK"
 
     def testEmail(self):
